@@ -19,14 +19,14 @@ def clear_by_source(engine: Engine, table_name, source):
             if i == 0:
                 with engine.connect() as conn:
                     s = text('create index ' +
-                             f'{index_name} on {table_name} (_source)')
+                             f'"{index_name}" on "{table_name}" (_source)')
                     try:
                         logger.info('CREATING INDEX')
                         conn.execute(s)
                         logger.info('DONE CREATING INDEX')
                     except ProgrammingError as e:
                         logger.error('Failed to create index %s', e)
-                    s = text(f'delete from {table_name} where _source=:source'
+                    s = text(f'delete from "{table_name}" where _source=:source'
                              ).params(source=source)
                     try:
                         logger.info('DELETING PAST ROWS')
@@ -67,7 +67,6 @@ def publish_flow(config, engine, mode='append', fast=False):
     if not config.get(CONFIG_TAXONOMY_ID):
         return None
     primaryKey = [f.replace(':', '-') for f in config.get(CONFIG_PRIMARY_KEY)]
-    primaryKey.append('_source')
     table_name = config.get(CONFIG_TAXONOMY_ID).replace('-', '_')
     source = get_source(config)
     if engine is not None:
